@@ -2,7 +2,6 @@
 //! and access to various system registers.
 
 #![cfg_attr(not(test), no_std)]
-#![cfg_attr(feature = "const_fn", feature(const_panic))] // Better panic messages
 #![cfg_attr(feature = "const_fn", feature(const_mut_refs))] // GDT add_entry()
 #![cfg_attr(feature = "const_fn", feature(const_fn_fn_ptr_basics))] // IDT new()
 #![cfg_attr(feature = "const_fn", feature(const_fn_trait_bound))] // PageSize marker trait
@@ -11,6 +10,7 @@
 #![cfg_attr(feature = "doc_cfg", feature(doc_cfg))]
 #![warn(missing_docs)]
 #![deny(missing_debug_implementations)]
+#![deny(unsafe_op_in_unsafe_fn)]
 
 pub use crate::addr::{align_down, align_up, PhysAddr, VirtAddr};
 
@@ -45,19 +45,6 @@ macro_rules! const_fn {
     };
 }
 
-// Helper method for assert! in const fn. Uses out of bounds indexing if an
-// assertion fails and the "const_fn" feature is not enabled.
-#[cfg(feature = "const_fn")]
-macro_rules! const_assert {
-    ($cond:expr, $($arg:tt)+) => { assert!($cond, $($arg)*) };
-}
-#[cfg(not(feature = "const_fn"))]
-macro_rules! const_assert {
-    ($cond:expr, $($arg:tt)+) => {
-        [(); 1][!($cond as bool) as usize]
-    };
-}
-
 #[cfg(all(feature = "instructions", feature = "external_asm"))]
 pub(crate) mod asm;
 
@@ -67,7 +54,7 @@ pub mod registers;
 pub mod structures;
 
 /// Represents a protection ring level.
-#[derive(Debug, Copy, Clone, PartialEq, Eq)]
+#[derive(Debug, Copy, Clone, PartialEq, Eq, Hash)]
 #[repr(u8)]
 pub enum PrivilegeLevel {
     /// Privilege-level 0 (most privilege): This level is used by critical system-software
